@@ -1,6 +1,7 @@
 import sys
 
 from .base_client import Client, ClientConfig
-from .http_client import HttpClient, TransportType, RequestInfo
+from .http_client import HttpClient, RequestInfo, TransportType
+
 if sys.version_info >= (3, 5):
     from .async_client import AsyncClient, AsyncClientConfig, DataProvider
