@@ -82,8 +82,8 @@ class HttpRequest(TransportRequest):
     def _headers(host, data=None):
         # type (str, bytes) -> List[Tuple[str, str]]
         headers = [
-            ("User-Agent", "{agent}".format(agent=USER_AGENT)),
-            ("Host", "{host}".format(host=host)),
+            ("User-Agent", f"{USER_AGENT}"),
+            ("Host", f"{host}"),
             ("Connection", "keep-alive"),
             ("Accept", "*/*"),
         ]
@@ -91,18 +91,14 @@ class HttpRequest(TransportRequest):
         if data:
             headers.append(("Content-Type", "application/json"))
 
-            headers.append(
-                ("Content-length", "{length}".format(length=len(data)))
-            )
+            headers.append(("Content-length", f"{len(data)}"))
 
         return headers
 
     @classmethod
     def _post_or_put(cls, method, host, target, data, timeout=0):
         request_data = (
-            json.dumps(data, separators=(",", ":"))
-            if isinstance(data, dict)
-            else data
+            json.dumps(data, separators=(",", ":")) if isinstance(data, dict) else data
         )
 
         request_data = bytes(request_data, "utf-8")
@@ -139,9 +135,9 @@ class Http2Request(TransportRequest):
     def _headers(host, data=None):
         # type (str, bytes) -> List[Tuple[str, str]]
         headers = [
-            (":authority", "{host}".format(host=host)),
+            (":authority", f"{host}"),
             (":scheme", "https"),
-            ("user-agent", "{agent}".format(agent=USER_AGENT)),
+            ("user-agent", f"{USER_AGENT}"),
         ]
 
         headers.append(("accept", "application/json"))
@@ -149,18 +145,14 @@ class Http2Request(TransportRequest):
         if data:
             headers.append(("content-type", "application/json"))
 
-            headers.append(
-                ("content-length", "{length}".format(length=len(data)))
-            )
+            headers.append(("content-length", f"{len(data)}"))
 
         return headers
 
     @classmethod
     def _post_or_put(cls, method, host, target, data, timeout):
         request_data = (
-            json.dumps(data, separators=(",", ":"))
-            if isinstance(data, dict)
-            else data
+            json.dumps(data, separators=(",", ":")) if isinstance(data, dict) else data
         )
 
         request_data = bytes(request_data, "utf-8")
@@ -184,7 +176,9 @@ class Http2Request(TransportRequest):
     @classmethod
     def get(cls, host, target, timeout=0):
         request = Http2Request._request(
-            method="GET", target=target, headers=Http2Request._headers(host),
+            method="GET",
+            target=target,
+            headers=Http2Request._headers(host),
         )
 
         return cls(request, timeout=timeout)
@@ -259,7 +253,7 @@ class HttpResponse(TransportResponse):
             name, value = header
             name = name.decode("utf-8")
             value = value.decode("utf-8")
-            logger.debug("Got http header {}: {}".format(name, value))
+            logger.debug(f"Got http header {name}: {value}")
             self.headers[name] = value
 
 
@@ -273,7 +267,7 @@ class Http2Response(TransportResponse):
         # type: (h2.events.ResponseReceived) -> None
         for header in headers:
             name, value = header
-            logger.debug("Got http2 header {}: {}".format(name, value))
+            logger.debug(f"Got http2 header {name}: {value}")
 
             if name == b":status" or name == ":status":
                 self.status_code = int(value)
@@ -340,10 +334,7 @@ class HttpConnection(Connection):
         if not isinstance(request, HttpRequest):
             raise TypeError("Invalid request type for HttpConnection")
 
-        if (
-            self._connection.our_state == h11.IDLE
-            and not self._current_response
-        ):
+        if self._connection.our_state == h11.IDLE and not self._current_response:
             data = data + self._connection.send(request._request)
 
             if request._data:
@@ -407,10 +398,8 @@ class Http2Connection(Connection):
         )
         self._connection = h2.connection.H2Connection(config=config)
         self._connection.max_inbound_frame_size = 64 * 1024
-        self._responses = OrderedDict()  \
-            # type: OrderedDict[int, Http2Response]
-        self._data_to_send = OrderedDict() \
-            # type: OrderedDict[int, bytes]
+        self._responses = OrderedDict()  # type: OrderedDict[int, Http2Response]
+        self._data_to_send = OrderedDict()  # type: OrderedDict[int, bytes]
 
     @property
     def elapsed(self):
@@ -429,20 +418,14 @@ class Http2Connection(Connection):
         # The window changed for a single stream and the stream contains some
         # data to send, send it out now.
         if event.stream_id in self._data_to_send:
-            self._send_data(
-                event.stream_id,
-                self._data_to_send[event.stream_id]
-            )
+            self._send_data(event.stream_id, self._data_to_send[event.stream_id])
             return
 
         # The window changed for the whole connection, try to send out data for
         # every stream we have some data buffered.
         if event.stream_id == 0:
             for stream_id, data in self._data_to_send.items():
-                self._send_data(
-                    stream_id,
-                    data
-                )
+                self._send_data(stream_id, data)
 
     def _send_data(self, stream_id, data):
         window_size = self._connection.local_flow_control_window(stream_id)
@@ -450,13 +433,10 @@ class Http2Connection(Connection):
         request_size = len(data)
 
         bytes_to_send = min(window_size, request_size)
-        logger.debug("Sending data: stream id: {}; request size: {}; "
-                     "window size: {}; max frame size {}".format(
-                         stream_id,
-                         request_size,
-                         window_size,
-                         max_frame_size
-                     ))
+        logger.debug(
+            f"Sending data: stream id: {stream_id}; request size: {request_size}; "
+            f"window size: {window_size}; max frame size {max_frame_size}"
+        )
 
         while bytes_to_send > 0:
             chunk_size = min(bytes_to_send, max_frame_size)
@@ -464,10 +444,7 @@ class Http2Connection(Connection):
             if chunk_size >= len(data):
                 chunk, data = data, ""
             else:
-                chunk, data = (
-                    data[0:chunk_size],
-                    data[chunk_size:]
-                )
+                chunk, data = (data[0:chunk_size], data[chunk_size:])
 
             bytes_to_send -= chunk_size
             self._connection.send_data(stream_id, chunk)
@@ -484,13 +461,11 @@ class Http2Connection(Connection):
             raise TypeError("Invalid request type for HttpConnection")
 
         logger.debug(
-            "Making Http2 request {} {}.".format(
-                pprint.pformat(request._request), pprint.pformat(request._data)
-            )
+            f"Making Http2 request {pprint.pformat(request._request)} {pprint.pformat(request._data)}."
         )
 
         stream_id = self._connection.get_next_available_stream_id()
-        logger.debug("New stream id {}".format(stream_id))
+        logger.debug(f"New stream id {stream_id}")
 
         self._connection.send_headers(stream_id, request._request)
         self._send_data(stream_id, request._data)
@@ -552,7 +527,7 @@ class Http2Connection(Connection):
     def _handle_events(self, events):
         # type: (h2.events.Event) -> Optional[Http2Response]
         for event in events:
-            logger.info("Handling Http2 event: {}".format(repr(event)))
+            logger.info(f"Handling Http2 event: {repr(event)}")
 
             if isinstance(event, h2.events.ResponseReceived):
                 self._handle_response(event)
