@@ -27,8 +27,14 @@ from jsonschema.exceptions import SchemaError, ValidationError
 from logbook import Logger
 
 from .event_builders import ToDeviceMessage
-from .events import (AccountDataEvent, BadEventType, Event, InviteEvent,
-                     ToDeviceEvent, EphemeralEvent)
+from .events import (
+    AccountDataEvent,
+    BadEventType,
+    EphemeralEvent,
+    Event,
+    InviteEvent,
+    ToDeviceEvent,
+)
 from .events.presence import PresenceEvent
 from .http import TransportResponse
 from .log import logger_group
@@ -59,6 +65,8 @@ __all__ = [
     "EnablePushRuleResponse",
     "EnablePushRuleError",
     "ErrorResponse",
+    "GetOpenIDTokenError",
+    "GetOpenIDTokenResponse",
     "InviteInfo",
     "JoinResponse",
     "JoinError",
@@ -105,6 +113,7 @@ __all__ = [
     "RoomGetEventResponse",
     "RoomGetEventError",
     "RoomGetVisibilityResponse",
+    "RoomGetVisibilityError",
     "RoomPutAliasResponse",
     "RoomPutStateResponse",
     "RoomPutStateError",
@@ -180,7 +189,9 @@ def verify(schema, error_class, pass_arguments=True):
                     return error_class.from_dict(parsed_dict)
 
             return f(cls, parsed_dict, *args, **kwargs)
+
         return wrapper
+
     return decorator
 
 
@@ -273,7 +284,7 @@ class Device:
             parsed_dict["device_id"],
             parsed_dict["display_name"],
             parsed_dict["last_seen_ip"],
-            date
+            date,
         )
 
 
@@ -284,7 +295,8 @@ class Response:
     end_time: Optional[float] = field(default=None, init=False)
     timeout: int = field(default=0, init=False)
     transport_response: Optional[TransportResponse] = field(
-        init=False, default=None,
+        init=False,
+        default=None,
     )
 
     @property
@@ -311,11 +323,7 @@ class FileResponse(Response):
     filename: Optional[str] = field()
 
     def __str__(self):
-        return "{} bytes, content type: {}, filename: {}".format(
-            len(self.body),
-            self.content_type,
-            self.filename
-        )
+        return f"{len(self.body)} bytes, content type: {self.content_type}, filename: {self.filename}"
 
     @classmethod
     def from_data(cls, data, content_type, filename=None):
@@ -338,18 +346,18 @@ class ErrorResponse(Response):
 
     def __str__(self) -> str:
         if self.status_code and self.message:
-            e = "{} {}".format(self.status_code, self.message)
+            e = f"{self.status_code} {self.message}"
         elif self.message:
             e = self.message
         elif self.status_code:
-            e = "{} unknown error".format(self.status_code)
+            e = f"{self.status_code} unknown error"
         else:
             e = "unknown error"
 
         if self.retry_after_ms:
-            e = "{} - retry after {}ms".format(e, self.retry_after_ms)
+            e = f"{e} - retry after {self.retry_after_ms}ms"
 
-        return "{}: {}".format(self.__class__.__name__, e)
+        return f"{self.__class__.__name__}: {e}"
 
     @classmethod
     def from_dict(cls, parsed_dict: Dict[Any, Any]):
@@ -383,7 +391,7 @@ class _ErrorWithRoomId(ErrorResponse):
             parsed_dict["errcode"],
             parsed_dict.get("retry_after_ms"),
             parsed_dict.get("soft_logout", False),
-            room_id
+            room_id,
         )
 
 
@@ -405,21 +413,25 @@ class RoomSendError(_ErrorWithRoomId):
 
 class RoomGetStateError(_ErrorWithRoomId):
     """A response representing an unsuccessful room state query."""
+
     pass
 
 
 class RoomGetStateEventError(_ErrorWithRoomId):
     """A response representing an unsuccessful room state query."""
+
     pass
 
 
 class RoomGetEventError(ErrorResponse):
     """A response representing an unsuccessful room get event request."""
+
     pass
 
 
 class RoomPutStateError(_ErrorWithRoomId):
     """A response representing an unsuccessful room state sending request."""
+
     pass
 
 
@@ -429,21 +441,25 @@ class RoomRedactError(_ErrorWithRoomId):
 
 class RoomResolveAliasError(ErrorResponse):
     """A response representing an unsuccessful room alias query."""
+
     pass
 
 
 class RoomDeleteAliasError(ErrorResponse):
     """A response representing an unsuccessful room alias delete request."""
+
     pass
 
 
 class RoomPutAliasError(ErrorResponse):
     """A response representing an unsuccessful room alias put request."""
+
     pass
 
 
 class RoomGetVisibilityError(ErrorResponse):
     """A response representing an unsuccessful room get visibility request."""
+
     pass
 
 
@@ -481,6 +497,7 @@ class RoomInviteError(ErrorResponse):
 
 class RoomCreateError(ErrorResponse):
     """A response representing a unsuccessful create room request."""
+
     pass
 
 
@@ -500,6 +517,10 @@ class RoomMessagesError(_ErrorWithRoomId):
     pass
 
 
+class GetOpenIDTokenError(ErrorResponse):
+    pass
+
+
 class KeysUploadError(ErrorResponse):
     pass
 
@@ -541,8 +562,9 @@ class ShareGroupSessionError(_ErrorWithRoomId):
         except (SchemaError, ValidationError):
             return cls("unknown error")
 
-        return cls(parsed_dict["error"], parsed_dict["errcode"], room_id,
-                   users_shared_with)
+        return cls(
+            parsed_dict["error"], parsed_dict["errcode"], room_id, users_shared_with
+        )
 
 
 class DevicesError(ErrorResponse):
@@ -563,6 +585,7 @@ class JoinedMembersError(_ErrorWithRoomId):
 
 class JoinedRoomsError(ErrorResponse):
     """A response representing an unsuccessful joined rooms query."""
+
     pass
 
 
@@ -584,17 +607,20 @@ class ProfileGetAvatarError(ErrorResponse):
 
 class PresenceGetError(ErrorResponse):
     """Response representing a unsuccessful get presence request."""
+
     pass
 
 
 class PresenceSetError(ErrorResponse):
     """Response representing a unsuccessful set presence request."""
+
     pass
 
 
 class ProfileSetAvatarError(ErrorResponse):
     pass
 
+
 @dataclass
 class DiscoveryInfoError(ErrorResponse):
     pass
@@ -618,19 +644,25 @@ class DiscoveryInfoResponse(Response):
     @classmethod
     @verify(Schemas.discovery_info, DiscoveryInfoError)
     def from_dict(
-        cls, parsed_dict: Dict[str, Any],
+        cls,
+        parsed_dict: Dict[str, Any],
     ) -> Union["DiscoveryInfoResponse", DiscoveryInfoError]:
 
         homeserver_url = parsed_dict["m.homeserver"]["base_url"].rstrip("/")
 
-        identity_server_url = parsed_dict.get(
-            "m.identity_server", {},
-        ).get("base_url", "").rstrip("/") or None
+        identity_server_url = (
+            parsed_dict.get(
+                "m.identity_server",
+                {},
+            )
+            .get("base_url", "")
+            .rstrip("/")
+            or None
+        )
 
         return cls(homeserver_url, identity_server_url)
 
 
-
 @dataclass
 class RegisterErrorResponse(ErrorResponse):
     pass
@@ -643,9 +675,7 @@ class RegisterResponse(Response):
     access_token: str = field()
 
     def __str__(self) -> str:
-        return "Registered {}, device id {}.".format(
-            self.user_id, self.device_id,
-        )
+        return f"Registered {self.user_id}, device id {self.device_id}."
 
     @classmethod
     @verify(Schemas.register, RegisterErrorResponse)
@@ -681,9 +711,7 @@ class LoginResponse(Response):
     access_token: str = field()
 
     def __str__(self) -> str:
-        return "Logged in as {}, device id: {}.".format(
-            self.user_id, self.device_id
-        )
+        return f"Logged in as {self.user_id}, device id: {self.device_id}."
 
     @classmethod
     @verify(Schemas.login, LoginError)
@@ -728,7 +756,7 @@ class JoinedMembersResponse(Response):
             user = RoomMember(
                 user_id,
                 user_info.get("display_name", None),
-                user_info.get("avatar_url", None)
+                user_info.get("avatar_url", None),
             )
             members.append(user)
 
@@ -795,12 +823,7 @@ class DownloadResponse(FileResponse):
     """A response representing a successful download request."""
 
     @classmethod
-    def from_data(
-            cls,
-            data: bytes,
-            content_type: str,
-            filename: Optional[str] = None
-    ):
+    def from_data(cls, data: bytes, content_type: str, filename: Optional[str] = None):
         # type: (...) -> Union[DownloadResponse, DownloadError]
         if isinstance(data, bytes):
             return cls(body=data, content_type=content_type, filename=filename)
@@ -816,12 +839,7 @@ class ThumbnailResponse(FileResponse):
     """A response representing a successful thumbnail request."""
 
     @classmethod
-    def from_data(
-            cls,
-            data: bytes,
-            content_type: str,
-            filename: Optional[str] = None
-    ):
+    def from_data(cls, data: bytes, content_type: str, filename: Optional[str] = None):
         # type: (...) -> Union[ThumbnailResponse, ThumbnailError]
         if not content_type.startswith("image/"):
             return ThumbnailError(f"invalid content type: {content_type}")
@@ -943,8 +961,7 @@ class RoomGetEventResponse(Response):
         pass_arguments=False,
     )
     def from_dict(
-        cls,
-        parsed_dict: Dict[str, Any]
+        cls, parsed_dict: Dict[str, Any]
     ) -> Union["RoomGetEventResponse", RoomGetEventError]:
         event = Event.parse_event(parsed_dict)
         resp = cls()
@@ -954,6 +971,7 @@ class RoomGetEventResponse(Response):
 
 class RoomPutStateResponse(RoomEventIdResponse):
     """A response indicating successful sending of room state."""
+
     @staticmethod
     def create_error(parsed_dict, room_id):
         return RoomPutStateError.from_dict(parsed_dict, room_id)
@@ -974,6 +992,7 @@ class RoomResolveAliasResponse(Response):
         room_id (str): The resolved id of the room.
         servers (List[str]): Servers participating in the room.
     """
+
     room_alias: str = field()
     room_id: str = field()
     servers: List[str] = field()
@@ -997,8 +1016,8 @@ class RoomResolveAliasResponse(Response):
 
 @dataclass
 class RoomDeleteAliasResponse(Response):
-    """A response containing the result of deleting an alias.
-    """
+    """A response containing the result of deleting an alias."""
+
     room_alias: str = field()
 
     @classmethod
@@ -1009,8 +1028,8 @@ class RoomDeleteAliasResponse(Response):
 
 @dataclass
 class RoomPutAliasResponse(Response):
-    """A response containing the result of adding an alias.
-    """
+    """A response containing the result of adding an alias."""
+
     room_alias: str = field()
     room_id: str = field()
 
@@ -1022,8 +1041,8 @@ class RoomPutAliasResponse(Response):
 
 @dataclass
 class RoomGetVisibilityResponse(Response):
-    """A response containing the result of a get visibility request.
-    """
+    """A response containing the result of a get visibility request."""
+
     room_id: str = field()
     visibility: str = field()
 
@@ -1170,11 +1189,7 @@ class DeleteDevicesAuthResponse(Response):
         parsed_dict: Dict[Any, Any],
     ):
         # type: (...) -> Union[DeleteDevicesAuthResponse, ErrorResponse]
-        return cls(
-            parsed_dict["session"],
-            parsed_dict["flows"],
-            parsed_dict["params"]
-        )
+        return cls(parsed_dict["session"], parsed_dict["flows"], parsed_dict["params"])
 
 
 class DeleteDevicesResponse(EmptyResponse):
@@ -1189,7 +1204,7 @@ class RoomMessagesResponse(Response):
 
     chunk: List[Union[Event, BadEventType]] = field()
     start: str = field()
-    end: str = field()
+    end: str = field(default=None)
 
     @classmethod
     @verify(Schemas.room_messages, RoomMessagesError)
@@ -1201,7 +1216,7 @@ class RoomMessagesResponse(Response):
         # type: (...) -> Union[RoomMessagesResponse, ErrorResponse]
         chunk: List[Union[Event, BadEventType]] = []
         chunk = SyncResponse._get_room_events(parsed_dict["chunk"])
-        return cls(room_id, chunk, parsed_dict["start"], parsed_dict["end"])
+        return cls(room_id, chunk, parsed_dict["start"], parsed_dict.get("end"))
 
 
 @dataclass
@@ -1226,12 +1241,14 @@ class RoomIdResponse(Response):
 @dataclass
 class RoomCreateResponse(Response):
     """Response representing a successful create room request."""
-    room_id: str = field()
 
+    room_id: str = field()
 
     @classmethod
     @verify(
-        Schemas.room_create_response, RoomCreateError, pass_arguments=False,
+        Schemas.room_create_response,
+        RoomCreateError,
+        pass_arguments=False,
     )
     def from_dict(
         cls,
@@ -1255,11 +1272,31 @@ class RoomLeaveResponse(EmptyResponse):
 
 class RoomForgetResponse(_EmptyResponseWithRoomId):
     """Response representing a successful forget room request."""
+
     @staticmethod
     def create_error(parsed_dict, room_id):
         return RoomForgetError.from_dict(parsed_dict, room_id)
 
 
+@dataclass
+class GetOpenIDTokenResponse(Response):
+    access_token: str = field()
+    expires_in: int = field()
+    matrix_server_name: str = field()
+    token_type: str = field()
+
+    @classmethod
+    @verify(Schemas.get_openid_token, GetOpenIDTokenError)
+    def from_dict(cls, parsed_dict: Dict[Any, Any]):
+        # type: (...) -> Union[GetOpenIDTokenResponse, ErrorResponse]
+        access_token = parsed_dict["access_token"]
+        expires_in = parsed_dict["expires_in"]
+        matrix_server_name = parsed_dict["matrix_server_name"]
+        token_type = parsed_dict["token_type"]
+
+        return cls(access_token, expires_in, matrix_server_name, token_type)
+
+
 @dataclass
 class KeysUploadResponse(Response):
     curve25519_count: int = field()
@@ -1278,7 +1315,8 @@ class KeysQueryResponse(Response):
     device_keys: Dict = field()
     failures: Dict = field()
     changed: Dict[str, Dict[str, Any]] = field(
-        init=False, default_factory=dict,
+        init=False,
+        default_factory=dict,
     )
 
     @classmethod
@@ -1397,11 +1435,7 @@ class ProfileGetResponse(Response):
     other_info: Dict[Any, Any] = field(default_factory=dict)
 
     def __str__(self) -> str:
-        return "Display name: {}, avatar URL: {}, other info: {}".format(
-            self.displayname,
-            self.avatar_url,
-            self.other_info,
-        )
+        return f"Display name: {self.displayname}, avatar URL: {self.avatar_url}, other info: {self.other_info}"
 
     @classmethod
     @verify(Schemas.get_profile, ProfileGetError)
@@ -1410,8 +1444,11 @@ class ProfileGetResponse(Response):
         return cls(
             parsed_dict.get("displayname"),
             parsed_dict.get("avatar_url"),
-            {k: v for k, v in parsed_dict.items()
-             if k not in ("displayname", "avatar_url")},
+            {
+                k: v
+                for k, v in parsed_dict.items()
+                if k not in ("displayname", "avatar_url")
+            },
         )
 
 
@@ -1427,7 +1464,7 @@ class ProfileGetDisplayNameResponse(Response):
     displayname: Optional[str] = None
 
     def __str__(self) -> str:
-        return "Display name: {}".format(self.displayname)
+        return f"Display name: {self.displayname}"
 
     @classmethod
     @verify(Schemas.get_displayname, ProfileGetDisplayNameError)
@@ -1457,7 +1494,7 @@ class ProfileGetAvatarResponse(Response):
     avatar_url: Optional[str] = None
 
     def __str__(self) -> str:
-        return "Avatar URL: {}".format(self.avatar_url)
+        return f"Avatar URL: {self.avatar_url}"
 
     @classmethod
     @verify(Schemas.get_avatar, ProfileGetAvatarError)
@@ -1500,16 +1537,14 @@ class PresenceGetResponse(Response):
     @classmethod
     @verify(Schemas.get_presence, PresenceGetError, pass_arguments=False)
     def from_dict(
-        cls,
-        parsed_dict: Dict[Any, Any],
-        user_id: str
+        cls, parsed_dict: Dict[Any, Any], user_id: str
     ) -> Union["PresenceGetResponse", PresenceGetError]:
         return cls(
             user_id,
             parsed_dict.get("presence", "offline"),
             parsed_dict.get("last_active_ago"),
             parsed_dict.get("currently_active"),
-            parsed_dict.get("status_msg")
+            parsed_dict.get("status_msg"),
         )
 
 
@@ -1595,20 +1630,21 @@ class RoomContextResponse(Response):
         room_id: str,
     ):
         # type: (...) -> Union[RoomContextResponse, ErrorResponse]
-        events_before = SyncResponse._get_room_events(
-            parsed_dict["events_before"]
-        )
-        events_after = SyncResponse._get_room_events(
-            parsed_dict["events_after"]
-        )
+        events_before = SyncResponse._get_room_events(parsed_dict["events_before"])
+        events_after = SyncResponse._get_room_events(parsed_dict["events_after"])
         event = Event.parse_event(parsed_dict["event"])
 
-        state = SyncResponse._get_room_events(
-            parsed_dict["state"]
-        )
+        state = SyncResponse._get_room_events(parsed_dict["state"])
 
-        return cls(room_id, parsed_dict["start"], parsed_dict["end"],
-                   event, events_before, events_after, state)
+        return cls(
+            room_id,
+            parsed_dict["start"],
+            parsed_dict["end"],
+            event,
+            events_before,
+            events_after,
+            state,
+        )
 
 
 @dataclass
@@ -1624,7 +1660,7 @@ class SyncResponse(Response):
     def __str__(self) -> str:
         result = []
         for room_id, room_info in self.rooms.join.items():
-            room_header = "  Messages for room {}:\n    ".format(room_id)
+            room_header = f"  Messages for room {room_id}:\n    "
             messages = []
             for event in room_info.timeline.events:
                 messages.append(str(event))
@@ -1635,16 +1671,16 @@ class SyncResponse(Response):
         if len(self.to_device_events) > 0:
             result.append("  Device messages:")
             for event in self.to_device_events:
-                result.append("    {}".format(event))
+                result.append(f"    {event}")
 
         body = "\n".join(result)
-        string = ("Sync response until batch: {}:\n{}").format(
-            self.next_batch, body
-        )
+        string = ("Sync response until batch: {}:\n{}").format(self.next_batch, body)
         return string
 
     @staticmethod
-    def _get_room_events(parsed_dict: List[Dict[Any, Any]]) -> List[Union[Event, BadEventType]]:
+    def _get_room_events(
+        parsed_dict: List[Dict[Any, Any]]
+    ) -> List[Union[Event, BadEventType]]:
         events: List[Union[Event, BadEventType]] = []
 
         for event_dict in parsed_dict:
@@ -1673,9 +1709,7 @@ class SyncResponse(Response):
 
         events = SyncResponse._get_room_events(parsed_dict.get("events", []))
 
-        return Timeline(
-            events, parsed_dict["limited"], parsed_dict.get("prev_batch")
-        )
+        return Timeline(events, parsed_dict["limited"], parsed_dict.get("prev_batch"))
 
     @staticmethod
     def _get_state(parsed_dict: Dict[Any, Any]) -> List[Union[Event, BadEventType]]:
@@ -1725,9 +1759,7 @@ class SyncResponse(Response):
         events = SyncResponse._get_room_events(timeline_events)
         timeline = Timeline(events, limited, prev_batch)
 
-        ephemeral_event_list = SyncResponse._get_ephemeral_events(
-            ephemeral_events
-        )
+        ephemeral_event_list = SyncResponse._get_ephemeral_events(ephemeral_events)
 
         summary = RoomSummary(
             summary_events.get("m.invited_member_count"),
@@ -1758,26 +1790,26 @@ class SyncResponse(Response):
         left_rooms: Dict[str, RoomInfo] = {}
 
         for room_id, room_dict in parsed_dict.get("invite", {}).items():
-            state = SyncResponse._get_invite_state(room_dict["invite_state"])
+            state = SyncResponse._get_invite_state(room_dict.get("invite_state", {}))
             invite_info = InviteInfo(state)
             invited_rooms[room_id] = invite_info
 
         for room_id, room_dict in parsed_dict.get("leave", {}).items():
-            state = SyncResponse._get_state(room_dict["state"])
-            timeline = SyncResponse._get_timeline(room_dict["timeline"])
+            state = SyncResponse._get_state(room_dict.get("state", {}))
+            timeline = SyncResponse._get_timeline(room_dict.get("timeline", {}))
             leave_info = RoomInfo(timeline, state, [], [])
             left_rooms[room_id] = leave_info
 
         for room_id, room_dict in parsed_dict.get("join", {}).items():
             join_info = SyncResponse._get_join_info(
-                room_dict["state"]["events"],
-                room_dict["timeline"]["events"],
-                room_dict["timeline"].get("prev_batch"),
-                room_dict["timeline"]["limited"],
-                room_dict["ephemeral"]["events"],
+                room_dict.get("state", {}).get("events", []),
+                room_dict.get("timeline", {}).get("events", []),
+                room_dict.get("timeline", {}).get("prev_batch"),
+                room_dict.get("timeline", {}).get("limited", False),
+                room_dict.get("ephemeral", {}).get("events", []),
                 room_dict.get("summary", {}),
                 room_dict.get("unread_notifications", {}),
-                room_dict["account_data"]["events"],
+                room_dict.get("account_data", {}).get("events", []),
             )
 
             joined_rooms[room_id] = join_info
@@ -1810,8 +1842,7 @@ class SyncResponse(Response):
 
         key_count_dict = parsed_dict.get("device_one_time_keys_count", {})
         key_count = DeviceOneTimeKeyCount(
-            key_count_dict.get("curve25519"),
-            key_count_dict.get("signed_curve25519")
+            key_count_dict.get("curve25519"), key_count_dict.get("signed_curve25519")
         )
 
         devices = DeviceList(
@@ -1847,12 +1878,14 @@ class UploadFilterResponse(Response):
             future requests to restrict which events are returned to the
             client.
     """
+
     filter_id: str = field()
 
     @classmethod
     @verify(Schemas.upload_filter, UploadFilterError)
     def from_dict(
-        cls, parsed_dict: Dict[Any, Any],
+        cls,
+        parsed_dict: Dict[Any, Any],
     ) -> Union["UploadFilterResponse", UploadFilterError]:
         return cls(parsed_dict["filter_id"])
 
@@ -1869,7 +1902,8 @@ class WhoamiResponse(Response):
     @classmethod
     @verify(Schemas.whoami, WhoamiError)
     def from_dict(
-        cls, parsed_dict: Dict[Any, Any],
+        cls,
+        parsed_dict: Dict[Any, Any],
     ) -> Union["WhoamiResponse", WhoamiError]:
         return cls(parsed_dict["user_id"])
 
@@ -1947,6 +1981,7 @@ class RoomUpdateAliasError(ErrorResponse):
 class RoomUpdateAliasResponse(EmptyResponse):
     pass
 
+
 class RoomUpgradeError(ErrorResponse):
     pass
 
