@@ -7,69 +7,69 @@ import pdb
 
 from nio.api import PushRuleKind
 from nio.events import (
+    AccountDataEvent,
     BadEvent,
+    CallAnswerEvent,
+    CallCandidatesEvent,
+    CallEvent,
+    CallHangupEvent,
+    CallInviteEvent,
+    DummyEvent,
+    EphemeralEvent,
+    Event,
+    ForwardedRoomKeyEvent,
+    FullyReadEvent,
+    InviteAliasEvent,
+    InviteEvent,
+    InviteMemberEvent,
+    InviteNameEvent,
+    KeyVerificationAccept,
+    KeyVerificationCancel,
+    KeyVerificationKey,
+    KeyVerificationMac,
+    KeyVerificationStart,
+    MegolmEvent,
     OlmEvent,
     PowerLevelsEvent,
+    PushContainsDisplayName,
+    PushEventMatch,
+    PushRoomMemberCount,
+    PushRule,
+    PushRuleset,
+    PushRulesEvent,
+    PushSenderNotificationPermission,
+    PushUnknownCondition,
+    Receipt,
+    ReceiptEvent,
     RedactedEvent,
     RedactionEvent,
-    StickerEvent,
     RoomAliasEvent,
+    RoomAvatarEvent,
     RoomCreateEvent,
+    RoomEncryptedImage,
+    RoomEncryptionEvent,
     RoomGuestAccessEvent,
     RoomHistoryVisibilityEvent,
     RoomJoinRulesEvent,
+    RoomKeyEvent,
+    RoomKeyRequest,
+    RoomKeyRequestCancellation,
     RoomMemberEvent,
     RoomMessageEmote,
     RoomMessageNotice,
     RoomMessageText,
     RoomNameEvent,
     RoomTopicEvent,
-    RoomAvatarEvent,
-    ToDeviceEvent,
-    UnknownBadEvent,
-    Event,
-    RoomEncryptionEvent,
-    InviteEvent,
-    RoomKeyEvent,
-    ForwardedRoomKeyEvent,
-    MegolmEvent,
-    UnknownEncryptedEvent,
-    InviteMemberEvent,
-    InviteAliasEvent,
-    InviteNameEvent,
-    EphemeralEvent,
-    TypingNoticeEvent,
-    Receipt,
-    ReceiptEvent,
-    AccountDataEvent,
-    UnknownAccountDataEvent,
-    FullyReadEvent,
-    CallEvent,
-    CallAnswerEvent,
-    CallHangupEvent,
-    CallInviteEvent,
-    CallCandidatesEvent,
-    KeyVerificationStart,
-    KeyVerificationAccept,
-    KeyVerificationCancel,
-    RoomEncryptedImage,
-    KeyVerificationKey,
-    KeyVerificationMac,
+    StickerEvent,
     TagEvent,
-    DummyEvent,
-    RoomKeyRequest,
-    RoomKeyRequestCancellation,
-    PushRule,
-    PushRuleset,
-    PushRulesEvent,
-    PushEventMatch,
-    PushContainsDisplayName,
-    PushRoomMemberCount,
-    PushSenderNotificationPermission,
-    PushUnknownCondition,
+    ToDeviceEvent,
+    TypingNoticeEvent,
+    UnknownAccountDataEvent,
+    UnknownBadEvent,
+    UnknownEncryptedEvent,
 )
-from nio.rooms import MatrixRoom
 from nio.responses import RoomSummary
+from nio.rooms import MatrixRoom
 
 
 class TestClass:
@@ -174,7 +174,7 @@ class TestClass:
         assert levels.get_message_event_required_level("m.room.message") == 25
         assert levels.get_message_event_required_level("m.room.undefined") == 0
         assert levels.get_notification_required_level("room") == 60
-        assert levels.get_notification_required_level("non_existant") == 50
+        assert levels.get_notification_required_level("non_existent") == 50
 
         assert levels.get_user_level(admin) == 100
         assert levels.get_user_level(user) == 0
@@ -262,9 +262,7 @@ class TestClass:
             ("m.room.power_levels", "power_levels.json"),
             ("m.room.encryption", "room_encryption.json"),
         ]:
-            parsed_dict = TestClass._load_response(
-                "tests/data/events/{}".format(event_file)
-            )
+            parsed_dict = TestClass._load_response(f"tests/data/events/{event_file}")
             parsed_dict.pop("state_key")
 
             event = Event.parse_event(parsed_dict)
@@ -278,9 +276,7 @@ class TestClass:
             ("m.room.canonical_alias", "alias.json"),
             ("m.room.name", "name.json"),
         ]:
-            parsed_dict = TestClass._load_response(
-                "tests/data/events/{}".format(event_file)
-            )
+            parsed_dict = TestClass._load_response(f"tests/data/events/{event_file}")
             parsed_dict.pop("state_key")
 
             event = InviteEvent.parse_event(parsed_dict)
@@ -293,9 +289,7 @@ class TestClass:
             ("m.room.canonical_alias", "alias.json"),
             ("m.room.name", "name.json"),
         ]:
-            parsed_dict = TestClass._load_response(
-                "tests/data/events/{}".format(event_file)
-            )
+            parsed_dict = TestClass._load_response(f"tests/data/events/{event_file}")
             parsed_dict.pop("type")
 
             event = InviteEvent.parse_event(parsed_dict)
@@ -307,9 +301,7 @@ class TestClass:
             (InviteAliasEvent, "alias.json"),
             (InviteNameEvent, "name.json"),
         ]:
-            parsed_dict = TestClass._load_response(
-                "tests/data/events/{}".format(event_file)
-            )
+            parsed_dict = TestClass._load_response(f"tests/data/events/{event_file}")
             event = InviteEvent.parse_event(parsed_dict)
             assert isinstance(event, event_type)
 
@@ -359,10 +351,7 @@ class TestClass:
         # Warning: this is directly tied to the above file; any changes below
         # need to be reflected there too.
         receipt = Receipt(
-            "$152037280074GZeOm:localhost",
-            "m.read",
-            "@bob:example.com",
-            1520372804619
+            "$152037280074GZeOm:localhost", "m.read", "@bob:example.com", 1520372804619
         )
 
         assert isinstance(event, ReceiptEvent)
@@ -381,16 +370,12 @@ class TestClass:
         # Warning: this is directly tied to the above file; any changes below
         # need to be reflected there too.
         receipt = Receipt(
-            "$152037280074GZeOm:localhost",
-            "m.read",
-            "@bob:example.com",
-            1520372804619
+            "$152037280074GZeOm:localhost", "m.read", "@bob:example.com", 1520372804619
         )
 
         assert isinstance(event, ReceiptEvent)
         assert receipt in event.receipts
 
-
     def test_account_data_event(self):
         event = AccountDataEvent.parse_event({})
 
@@ -413,9 +398,7 @@ class TestClass:
             (CallCandidatesEvent, "call_candidates.json"),
             (CallHangupEvent, "call_hangup.json"),
         ]:
-            parsed_dict = TestClass._load_response(
-                "tests/data/events/{}".format(event_file)
-            )
+            parsed_dict = TestClass._load_response(f"tests/data/events/{event_file}")
             parsed_dict["content"].pop("call_id")
             event = CallEvent.parse_event(parsed_dict)
             assert isinstance(event, BadEvent)
@@ -427,9 +410,7 @@ class TestClass:
             (CallCandidatesEvent, "call_candidates.json"),
             (CallHangupEvent, "call_hangup.json"),
         ]:
-            parsed_dict = TestClass._load_response(
-                "tests/data/events/{}".format(event_file)
-            )
+            parsed_dict = TestClass._load_response(f"tests/data/events/{event_file}")
             event = CallEvent.parse_event(parsed_dict)
             assert isinstance(event, event_type)
 
@@ -441,9 +422,7 @@ class TestClass:
             (KeyVerificationMac, "key_mac.json"),
             (KeyVerificationCancel, "key_cancel.json"),
         ]:
-            parsed_dict = TestClass._load_response(
-                "tests/data/events/{}".format(event_file)
-            )
+            parsed_dict = TestClass._load_response(f"tests/data/events/{event_file}")
             event = ToDeviceEvent.parse_event(parsed_dict)
             assert isinstance(event, event_type)
 
@@ -455,9 +434,7 @@ class TestClass:
             (KeyVerificationMac, "key_mac.json"),
             (KeyVerificationCancel, "key_cancel.json"),
         ]:
-            parsed_dict = TestClass._load_response(
-                "tests/data/events/{}".format(event_file)
-            )
+            parsed_dict = TestClass._load_response(f"tests/data/events/{event_file}")
             parsed_dict["content"].pop("transaction_id")
             event = ToDeviceEvent.parse_event(parsed_dict)
             assert isinstance(event, UnknownBadEvent)
@@ -545,16 +522,18 @@ class TestClass:
         room = MatrixRoom("!test:example.org", "@alice:example.com")
         name = "Alice"
 
-        event = Event.from_dict({
-            "event_id": "!test:example.org",
-            "room_id": room.room_id,
-            "origin_server_ts": 0,
-            "sender": "@alice:example.org",
-            "type": "m.test",
-            "words": "foo bar",
-            "int": 0,
-            "content": { "body": "a,here c" },
-        })
+        event = Event.from_dict(
+            {
+                "event_id": "!test:example.org",
+                "room_id": room.room_id,
+                "origin_server_ts": 0,
+                "sender": "@alice:example.org",
+                "type": "m.test",
+                "words": "foo bar",
+                "int": 0,
+                "content": {"body": "a,here c"},
+            }
+        )
 
         args = (event, room, name)
 
@@ -562,16 +541,16 @@ class TestClass:
 
         must_succeed = [
             ("type", "m.test"),
-            ("type", "M*T"),              # glob + ignoring case
-            ("content.body", "heRe"),     # word boundaries + ignoring case
-            ("content.body", "a"),        # word at the start of the string
-            ("content.body", "c"),        # word at the end of the string
+            ("type", "M*T"),  # glob + ignoring case
+            ("content.body", "heRe"),  # word boundaries + ignoring case
+            ("content.body", "a"),  # word at the start of the string
+            ("content.body", "c"),  # word at the end of the string
             ("content.body", "[a-z]*c"),  # more glob patterns
         ]
 
         must_fail = [
-            ("int", "0"),             # only match string values
-            ("words", "foo"),         # match words only for content.body
+            ("int", "0"),  # only match string values
+            ("words", "foo"),  # match words only for content.body
             ("content.body", "her"),  # not a full word match
         ]
 
